@@ -12,13 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
-import mock
-
 from openstack_auth import policy
 from openstack_dashboard import api as dash_api
-
 from troveclient import common
 
 from trove_dashboard import api
@@ -87,6 +86,7 @@ class DatabasesBackupsTests(test.TestCase):
             backupName,
             database.id,
             backupDesc,
+            "",
             "")
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, INDEX_URL)
@@ -138,7 +138,8 @@ class DatabasesBackupsTests(test.TestCase):
             backupName,
             database.id,
             backupDesc,
-            backupParent.id)
+            backupParent.id,
+            "")
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
@@ -213,7 +214,7 @@ class DatabasesBackupsTests(test.TestCase):
         url = RESTORE_URL + '?backup=%s' % self.database_backups.first().id
         res = self.client.get(url)
         self.assert_mock_multiple_calls_with_same_arguments(
-            self.mock_check, 4, mock.call((), test.IsHttpRequest()))
+            self.mock_check, 5, mock.call((), test.IsHttpRequest()))
         self.mock_backup_get.assert_called_once_with(
             test.IsHttpRequest(), test.IsA(str))
         self.mock_backup_list.assert_called_once_with(test.IsHttpRequest())
