@@ -15,8 +15,6 @@
 from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
-import six
-
 from horizon import exceptions
 from horizon import forms
 from horizon import messages
@@ -105,11 +103,10 @@ class CreateConfigurationForm(forms.SelfHandlingForm):
                                            datastore_version=datastore_version)
 
             messages.success(request, _('Created configuration group'))
-        except Exception as e:
+        except Exception:
             redirect = reverse("horizon:project:database_configurations:index")
             exceptions.handle(request, _('Unable to create configuration '
-                                         'group. %s')
-                              % six.text_type(e), redirect=redirect)
+                                         'group.'), redirect=redirect)
         return True
 
 
@@ -177,15 +174,23 @@ class AddParameterForm(forms.SelfHandlingForm):
     def handle(self, request, data):
         try:
             (config_param_manager
-                .get(request, self.initial["configuration_id"])
-                .add_param(data["name"],
-                           config_param_manager.adjust_type(
-                               config_param_manager.find_parameter(
-                                   data["name"], self.parameters).type,
-                               data["value"])))
+             .get(request, self.initial["configuration_id"])
+             .add_param(data["name"],
+                        config_param_manager.adjust_type(
+                            config_param_manager.find_parameter(
+                                data["name"], self.parameters).type,
+                            data["value"])))
+
+            new_values = config_param_manager.get(
+                request, self.initial["configuration_id"], use_cache=True
+            ).to_json()
+            api.trove.configuration_update(
+                request, self.initial["configuration_id"], new_values)
+
             messages.success(request, _('Successfully added parameter'))
-        except Exception as e:
+        except Exception:
             redirect = reverse("horizon:project:database_configurations:index")
-            exceptions.handle(request, _('Unable to add new parameter: %s')
-                              % six.text_type(e), redirect=redirect)
+            exceptions.handle(request,
+                              _('Unable to add new parameter.'),
+                              redirect=redirect)
         return True
