@@ -15,8 +15,12 @@
 from urllib import parse as urlparse
 
 from django.conf import settings
+from django import template
 from django.template import defaultfilters as d_filters
 from django import urls
+from django.urls import reverse
+from django.utils import html
+from django.utils import safestring
 
 from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
@@ -33,7 +37,7 @@ from trove_dashboard.content.database_backups \
     import tables as backup_tables
 
 
-ACTIVE_STATES = ("ACTIVE",)
+ACTIVE_STATES = ("ACTIVE", "HEALTHY",)
 
 
 class DeleteInstance(tables.DeleteAction):
@@ -570,11 +574,28 @@ def get_datastore_version(instance):
     return _("Not available")
 
 
+# NOTE(e0ne): the logic is based on
+# openstack_dashboard.dashboards.project.instances.tables.get_ips
+# Trove has a different instance addresses structure so we can't re-use
+# nova-related code as is.
+def get_ips(instance):
+    template_name = 'project/instances/_instance_ips.html'
+    ip_groups = {}
+
+    for address in getattr(instance, 'addresses', []):
+        ip_groups[address["type"]] = [address["address"]]
+
+    context = {
+        "ip_groups": ip_groups,
+    }
+    return template.loader.render_to_string(template_name, context)
+
+
 def get_host(instance):
     if hasattr(instance, "hostname"):
         return instance.hostname
     elif hasattr(instance, "ip") and instance.ip:
-        return instance.ip[0]
+        return get_ips(instance)
     return _("Not Assigned")
 
 
@@ -601,9 +622,82 @@ def get_databases(user):
     return _("-")
 
 
+class ReplicaColumn(tables.WrappingColumn):
+    """Customized column class.
+
+        So it that does complex processing on the replication
+        for a database instance.
+        """
+
+    instance_detail_url = "horizon:project:databases:detail"
+
+    def get_instance_link(self, instance_id):
+        request = self.table.request
+        url = reverse(self.instance_detail_url, args=(instance_id,))
+        instance = api.trove.instance_get(request, instance_id)
+        link = '<a href="%s">%s</a>' % (url, html.escape(instance.name))
+        return link
+
+    def get_raw_data(self, instance):
+        if hasattr(instance, "replicas"):
+            links = []
+            for replica in instance.replicas:
+                instance_id = replica["id"]
+                links.append(self.get_instance_link(instance_id))
+            replicas = ', '.join(links)
+            cell_text = ("Primary, has replicas: %s") % replicas
+            return safestring.mark_safe(cell_text)
+        if hasattr(instance, "replica_of"):
+            instance_id = instance.replica_of["id"]
+            link = self.get_instance_link(instance_id)
+            replica_of = _("Replica of %s")
+            return safestring.mark_safe(replica_of % link)
+        return _("-")
+
+
+class StopDatabase(tables.BatchAction):
+    name = "stop_database"
+    help_text = _("Stop database service inside an instance.")
+    action_type = "danger"
+
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Stop Database Service",
+            u"Stop Database Services",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Database Service stopped",
+            u"Database Services stopped",
+            count
+        )
+
+    def action(self, request, obj_id):
+        api.trove.stop_database(request, obj_id)
+
+    def allowed(self, request, instance):
+        return request.user.is_superuser and instance.status in ACTIVE_STATES
+
+
+class UpdateInstance(tables.LinkAction):
+    name = "edit_instance"
+    verbose_name = _("Update Instance")
+    url = "horizon:project:databases:edit_instance"
+    classes = ("btn-attach-config", "ajax-modal")
+
+    def allowed(self, request, instance=None):
+        return (instance.status in ACTIVE_STATES and
+                not hasattr(instance, 'configuration'))
+
+
 class InstancesTable(tables.DataTable):
     STATUS_CHOICES = (
         ("ACTIVE", True),
+        ("HEALTHY", True),
         ("BLOCKED", True),
         ("BUILD", None),
         ("FAILED", False),
@@ -617,6 +711,8 @@ class InstancesTable(tables.DataTable):
     STATUS_DISPLAY_CHOICES = (
         ("ACTIVE", pgettext_lazy("Current status of a Database Instance",
                                  u"Active")),
+        ("Healthy", pgettext_lazy("Current status of a Database Instance",
+                                  u"Healthy")),
         ("BLOCKED", pgettext_lazy("Current status of a Database Instance",
                                   u"Blocked")),
         ("BUILD", pgettext_lazy("Current status of a Database Instance",
@@ -648,14 +744,20 @@ class InstancesTable(tables.DataTable):
     size = tables.Column(get_size,
                          verbose_name=_("Size"),
                          attrs={'data-type': 'size'})
+    replication = ReplicaColumn("replicas",
+                                verbose_name=_("Replication Status"))
     volume = tables.Column(get_volume_size,
                            verbose_name=_("Volume Size"),
                            attrs={'data-type': 'size'})
     status = tables.Column("status",
                            verbose_name=_("Status"),
-                           status=True,
                            status_choices=STATUS_CHOICES,
                            display_choices=STATUS_DISPLAY_CHOICES)
+    operating_status = tables.Column("operating_status",
+                                     verbose_name=_("Operating Status"),
+                                     status=True,
+                                     status_choices=STATUS_CHOICES,
+                                     display_choices=STATUS_DISPLAY_CHOICES)
 
     class Meta(object):
         name = "databases"
@@ -664,6 +766,7 @@ class InstancesTable(tables.DataTable):
         row_class = UpdateRow
         table_actions = (LaunchLink, DeleteInstance)
         row_actions = (CreateBackup,
+                       UpdateInstance,
                        ResizeVolume,
                        ResizeInstance,
                        PromoteToReplicaSource,
@@ -673,6 +776,7 @@ class InstancesTable(tables.DataTable):
                        EjectReplicaSource,
                        DetachReplica,
                        RestartInstance,
+                       StopDatabase,
                        DeleteInstance)
 
 
