@@ -28,6 +28,8 @@ urlpatterns = [
     url(r'^$', views.IndexView.as_view(), name='index'),
     url(r'^launch$', views.LaunchInstanceView.as_view(), name='launch'),
     url(INSTANCES % '', views.DetailView.as_view(), name='detail'),
+    url(INSTANCES % 'edit_instance', views.UpdateInstanceView.as_view(),
+        name='edit_instance'),
     url(INSTANCES % 'resize_volume', views.ResizeVolumeView.as_view(),
         name='resize_volume'),
     url(INSTANCES % 'resize_instance', views.ResizeInstanceView.as_view(),
@@ -47,5 +49,5 @@ urlpatterns = [
         name='attach_config'),
     url(INSTANCES % 'manage_root', views.ManageRootView.as_view(),
         name='manage_root'),
-    url(BASEINSTANCES % 'logs/', include(logs_urls, namespace='logs')),
+    url(BASEINSTANCES % 'logs/', include((logs_urls, 'logs'))),
 ]
