@@ -283,6 +283,34 @@ class SetInstanceDetails(workflows.Step):
                    "locality", "availability_zone")
 
 
+class AddAccessAction(workflows.Action):
+    """Initialize the database access. This tab will honor
+        the settings which should be a list of permissions required:
+
+        * TROVE_ADD_USER_PERMS = []
+        * TROVE_ADD_DATABASE_PERMS = []
+        """
+    is_public = forms.BooleanField(label=_("Is Public"),
+                                   required=False)
+    allowed_cidrs = forms.MultiIPField(label=_("Allowed CIDRs"),
+                                       required=False,
+                                       version=forms.IPv4 | forms.IPv6,
+                                       mask=True,
+                                       widget=forms.TextInput(),
+                                       help_text=_("Comma-separated CIDRs "
+                                                   "to connect through."))
+
+    class Meta(object):
+        name = _("Database Access")
+        permissions = TROVE_ADD_PERMS
+        help_text_template = "project/databases/_launch_access_help.html"
+
+
+class DatabaseAccess(workflows.Step):
+    action_class = AddAccessAction
+    contributes = ["is_public", "allowed_cidrs"]
+
+
 class AddDatabasesAction(workflows.Action):
     """Initialize the database with users/databases. This tab will honor
     the settings which should be a list of permissions required:
@@ -368,12 +396,7 @@ class AdvancedAction(workflows.Action):
         required=False,
         min_value=1,
         initial=1,
-        help_text=_('Specify the number of replicas to be created'),
-        widget=forms.TextInput(attrs={
-            'class': 'switched',
-            'data-switch-on': 'initial_state',
-            'data-initial_state-master': _('Replica Count')
-        }))
+        help_text=_('Specify the number of replicas to be created'))
 
     def __init__(self, request, *args, **kwargs):
         if args[0]:
@@ -416,7 +439,7 @@ class AdvancedAction(workflows.Action):
             for b in backups:
                 if self.backup_id and b.id != self.backup_id:
                     continue
-                if b.status == 'COMPLETED':
+                if b.status in ['COMPLETED', 'RESTORED']:
                     choices.append((b.id, b.name))
         except Exception:
             choices = []
@@ -440,7 +463,7 @@ class AdvancedAction(workflows.Action):
         try:
             instances = self._get_instances()
             choices = sorted([(i.id, i.name) for i in
-                             instances if i.status == 'ACTIVE'],
+                             instances if i.status == 'HEALTHY'],
                              key=lambda i: i[1])
         except Exception:
             choices = []
@@ -494,6 +517,7 @@ class AdvancedAction(workflows.Action):
                 raise forms.ValidationError(
                     _("A master instance must be selected!"))
 
+            cleaned_data['flavor'] = None
             cleaned_data['backup'] = None
         else:
             cleaned_data['master'] = None
@@ -517,6 +541,7 @@ class LaunchInstance(workflows.Workflow):
     success_url = "horizon:project:databases:index"
     default_steps = (SetInstanceDetails,
                      dash_create_instance.SetNetwork,
+                     DatabaseAccess,
                      InitializeDatabase,
                      Advanced)
 
@@ -561,8 +586,7 @@ class LaunchInstance(workflows.Workflow):
     def _get_nics(self, context):
         netids = context.get('network_id', None)
         if netids:
-            return [{"net-id": netid, "v4-fixed-ip": ""}
-                    for netid in netids]
+            return [{"net-id": netid} for netid in netids]
         else:
             return None
 
@@ -582,6 +606,16 @@ class LaunchInstance(workflows.Workflow):
             locality = context['locality']
         return locality
 
+    def _get_access(self, context):
+        if not context['allowed_cidrs'] and not context['is_public']:
+            return None
+        access = {}
+        if context['allowed_cidrs'] != '':
+            access['allowed_cidrs'] = context['allowed_cidrs'].split(',')
+        if context['is_public']:
+            access['is_public'] = True
+        return access
+
     def handle(self, request, context):
         try:
             datastore, datastore_version = parse_datastore_and_version_text(
@@ -602,6 +636,7 @@ class LaunchInstance(workflows.Workflow):
                      context.get('master'), context['replica_count'],
                      context.get('config'), self._get_locality(context),
                      avail_zone)
+
             api.trove.instance_create(request,
                                       context['name'],
                                       context['volume'],
@@ -618,7 +653,8 @@ class LaunchInstance(workflows.Workflow):
                                           context),
                                       configuration=context.get('config'),
                                       locality=self._get_locality(context),
-                                      availability_zone=avail_zone)
+                                      availability_zone=avail_zone,
+                                      access=self._get_access(context))
             return True
         except Exception:
             exceptions.handle(request)
